<?php

class DnetwoBot_Admin {
	private static $initiated = false;

	public static function init() {
		if ( ! self::$initiated ) {
			self::init_hooks();
		}
	}

	public static function init_hooks() {
		self::$initiated = true;

		add_action( 'admin_init', array( 'DnetwoBot_Admin', 'admin_init' ) );
		add_action( 'admin_menu', array( 'DnetwoBot_Admin', 'admin_menu' ) );
		add_action( 'admin_notices', array( 'DnetwoBot_Admin', 'display_notice' ) );
		add_action( 'admin_enqueue_scripts', array( 'DnetwoBot_Admin', 'load_resources' ) );
		add_action( 'admin_post_update_bots', array( 'DnetwoBot_Admin', 'update_bots' ) );
		add_action( 'admin_init', array( 'DnetwoBot_Admin', 'start_session' ) );
		add_action( 'wp_login', array( 'DnetwoBot_Admin', 'end_session' ) );
		add_action( 'wp_logout', array( 'DnetwoBot_Admin', 'end_session' ) );
	}

	public static function admin_init() {
		register_setting( 'option_group', 'option_name', array(
			'sanitize_callback' => array(
				'DnetwoBot_Admin',
				'sanitize_callback'
			)
		) );

		add_settings_section(
			'account_section_id',
			__( 'Account Information', 'dnetwo-bot' ),
			function () {
				echo '<p>' . __( 'Please provide your account information below.', 'dnetwo-bot' ) . '</p>';
			},
			'general_page'
		);
		add_settings_field(
			'general_customer_id',
			__( 'Customer ID', 'dnetwo-bot' ),
			array(
				'DnetwoBot_Admin',
				'fill_general_customer_id'
			),
			'general_page',
			'account_section_id'
		);
		add_settings_field(
			'general_private_key',
			__( 'Private Key', 'dnetwo-bot' ),
			array(
				'DnetwoBot_Admin',
				'fill_general_private_key'
			),
			'general_page',
			'account_section_id'
		);
	}

	public static function fill_general_customer_id() {
		$customer_id = DnetwoBot_Helper::get_option_value( 'option_name', 'customer_id' );
		?>
		<input type="text" name="option_name[customer_id]" value="<?php echo esc_attr( $customer_id ) ?>" class="regular-text">
		<?php
	}

	public static function fill_general_private_key() {
		$private_key = DnetwoBot_Helper::get_option_value( 'option_name', 'private_key' );
		?>
		<textarea name="option_name[private_key]" rows="6" class="regular-text"><?php echo esc_attr( $private_key ) ?></textarea>
		<?php
	}

	public static function sanitize_callback( $options ) {
		foreach ( $options as $name => & $val ) {
			if ( in_array( $name, array( 'customer_id', 'private_key' ) ) ) {
				$val = strip_tags( $val );
			}
		}

		return $options;
	}

	public static function admin_menu() {
		add_menu_page(
			'dnetwo.bot » ' . __( 'Registration', 'dnetwo-bot' ),
			'dnetwo.bot',
			'manage_options',
			'dnetwo-bot-registration',
			array(
				'DnetwoBot_Admin',
				'display_registration_page'
			),
			'dashicons-format-status'
		);
		add_submenu_page(
			'dnetwo-bot-registration',
			'dnetwo.bot » ' . __( 'Registration', 'dnetwo-bot' ),
			__( 'Registration', 'dnetwo-bot' ),
			'manage_options',
			'dnetwo-bot-registration',
			array(
				'DnetwoBot_Admin',
				'display_registration_page'
			)
		);
		add_submenu_page(
			'dnetwo-bot-registration',
			'dnetwo.bot » ' . __( 'General', 'dnetwo-bot' ),
			__( 'General', 'dnetwo-bot' ),
			'manage_options',
			'dnetwo-bot-general',
			array(
				'DnetwoBot_Admin',
				'display_general_page'
			)
		);
		add_submenu_page(
			'dnetwo-bot-registration',
			'dnetwo.bot » ' . __( 'Chatbots', 'dnetwo-bot' ),
			__( 'Chatbots', 'dnetwo-bot' ),
			'manage_options',
			'dnetwo-bot-chatbots',
			array(
				'DnetwoBot_Admin',
				'display_chatbots_page'
			)
		);
	}

	public static function display_registration_page() {
		?>
        <div class="wrap">

            <h1><?php echo get_admin_page_title() ?></h1>

            <form class="dnetwo-form dnetwo-form--registration" action="<?php echo DNETWO_BOT_LOGIN_URL; ?>" method="GET" target="_blank">

                <h2><?php _e( 'Creating a new account in the Bot Management System', 'dnetwo-bot' ); ?></h2>
                <p><?php _e( 'Just enter your name, e-mail and phone below, and click "Register Now".', 'dnetwo-bot' ); ?></p>

                <table class="form-table">
                    <tbody>
                    <tr>
                        <th scope="row"><?php _e( 'Name', 'dnetwo-bot' ); ?></th>
                        <td>
                            <input type="text" name="name" class="regular-text">
                        </td>
                    </tr>
                    <tr>
                        <th scope="row"><?php _e( 'E-mail', 'dnetwo-bot' ); ?></th>
                        <td>
                            <input type="text" name="email" class="regular-text">
                        </td>
                    </tr>
                    <tr>
                        <th scope="row"><?php _e( 'Phone', 'dnetwo-bot' ); ?></th>
                        <td>
                            <input type="text" name="phone" class="regular-text">
                        </td>
                    </tr>
                    </tbody>
                </table>

                <p class="submit">
                    <input type="submit" value="<?php _e( 'Register Now', 'dnetwo-bot' ); ?>" class="button button-primary">
                </p>

            </form>

        </div>
		<?php
	}

	public static function display_general_page() {
		?>
		<div class="wrap">
			<h1><?php echo get_admin_page_title() ?></h1>

			<form class="dnetwo-form dnetwo-form--general" action="options.php" method="POST">
				<?php

				settings_fields( 'option_group' );
				do_settings_sections( 'general_page' );

				?>
                <p class="submit">
                    <input type="submit" value="<?php _e( 'Save Changes', 'dnetwo-bot' ); ?>" class="button button-primary">
                </p>
			</form>
		</div>
		<?php
	}

	public static function display_chatbots_page() {
		?>
        <div class="wrap">
            <h1><?php echo get_admin_page_title() ?></h1>
			<?php

            if ( isset( $_SESSION['updated'] ) ) {
	            DnetwoBot_Helper::display_notice( __( 'Settings saved.', 'dnetwo-bot' ) );
	            unset( $_SESSION['updated'] );
            }

			$customer_id = DnetwoBot_Helper::get_option_value( 'option_name', 'customer_id' );
			$private_key = DnetwoBot_Helper::get_option_value( 'option_name', 'private_key' );

			if ( DnetwoBot_Model::sync_bots( $customer_id, $private_key ) ) {

			    if ( $bots = DnetwoBot_Model::get_bots( $customer_id ) ) {

				    ?>
                    <form action="<?php echo esc_url( admin_url( 'admin-post.php' ) ) ?>" method="POST">

                        <input type="hidden" name="action" value="update_bots">
					    <?php wp_nonce_field( 'update_bots', 'update_bots_nonce' ); ?>

                        <h2><?php _e( 'Chatbots management', 'dnetwo-bot' ); ?></h2>
                        <p><?php _e( 'Below is a list of all the chatbots on your account that are available for management.', 'dnetwo-bot' ); ?></p>

                        <div class="dnetwo-bot-spoilers">
						    <?php

						    $i = 1;
						    foreach ( $bots as $bot ) :
							    ?>
                                <section class="dnetwo-bot-spoiler">

                                    <h3><?php echo __( 'Chatbot', 'dnetwo-bot' ), ' ', $i; ?></h3>

                                    <div class="dnetwo-bot-top-inputs wp-clearfix">
                                        <div class="dnetwo-bot-top-input-group">
                                            <label for="dnetwo-chatbot-<?php echo $i; ?>-name"><?php _e( 'Your chatbot name', 'dnetwo-bot' ); ?></label>
                                            <input type="text" value="<?php echo $bot->bot_name; ?>"
                                                   id="dnetwo-chatbot-<?php echo $i; ?>-name" class="regular-text"
                                                   readonly>
                                        </div>
                                        <div class="dnetwo-bot-top-input-group">
                                            <label for="dnetwo-chatbot-<?php echo $i; ?>-url"><?php _e( 'Corresponding chatbot URL', 'dnetwo-bot' ); ?></label>
                                            <input type="text" value="<?php echo $bot->bot_link; ?>"
                                                   id="dnetwo-chatbot-<?php echo $i; ?>-url" class="regular-text"
                                                   readonly>
                                        </div>
                                        <div class="dnetwo-bot-top-input-group">
                                            <a href="<?php echo DNETWO_BOT_UPGRADE_URL; ?>"
                                               target="_blank"><?php _e( 'Upgrade', 'dnetwo-bot' ); ?></a>
                                        </div>
                                    </div>

                                    <div class="dnetwo-bot-config">

                                        <p class="dnetwo-bot-config-title"><?php _e( 'Chatbot configuration', 'dnetwo-bot' ); ?></p>
                                        <p class="dnetwo-bot-config-desc"><?php _e( 'Below you can select the WordPress page you wish the chatbot to pop up.', 'dnetwo-bot' ); ?></p>

                                        <div class="dnetwo-bot-config-pages">
                                            <select name="bots[<?php echo $bot->id ?>][page_ids][]" class="regular-text"
                                                    multiple>
											    <?php
											    $pages = DnetwoBot_Helper::get_all_pages_and_posts();
											    foreach ( $pages as $page ) : /* @var WP_Post $page */ ?>
                                                    <option value="<?php echo $page->ID; ?>" <?php echo DnetwoBot_Model::page_id_in_bot_pages_ids( $page->ID, $bot->page_ids ) ? 'selected' : ''; ?>><?php echo $page->post_title; ?></option>
											    <?php endforeach; ?>
                                            </select>
                                            <input type="hidden" name="bots[<?php echo $bot->id ?>][page_ids][]"
                                                   value="empty">
                                        </div>

                                        <div class="dnetwo-bot-config-active">
                                            <label for="dnetwo-chatbot-<?php echo $i; ?>-active"><?php _e( 'Chatbot', 'dnetwo-bot' ); ?>
                                                <span><?php _e( 'activated', 'dnetwo-bot' ); ?></span></label>
                                            <input type="checkbox" name="bots[<?php echo $bot->id ?>][active][]"
                                                   value="yes"
                                                   id="dnetwo-chatbot-<?php echo $i; ?>-active" <?php echo $bot->active ? 'checked' : ''; ?>>
                                            <input type="hidden" name="bots[<?php echo $bot->id ?>][active][]"
                                                   value="empty">
                                        </div>

                                        <p><?php _e( 'You can customize your chatbot content from', 'dnetwo-bot' ); ?>
                                            <a href="<?php echo DNETWO_BOT_EDIT_URL, $bot->bot_key, '/'; ?>"
                                               target="_blank"><?php _e( 'here', 'dnetwo-bot' ); ?></a></p>

                                    </div>

                                </section>
							    <?php
							    $i ++;
						    endforeach; ?>
                        </div>

                        <p class="submit">
                            <input type="submit" value="<?php _e( 'Save Changes', 'dnetwo-bot' ); ?>"
                                   class="button button-primary">
                        </p>

                    </form>
				    <?php

			    } else {

				    ?>
                    <h2><?php _e( 'Chatbots management', 'dnetwo-bot' ); ?></h2>
                    <p><?php _e( 'You have not created any bot.', 'dnetwo-bot' ); ?></p>
				    <?php

                }

			} else {

			    ?>
                <h2><?php _e( 'Chatbots management', 'dnetwo-bot' ); ?></h2>
                <p><?php _e( 'For managing chatbots, provide your account information on', 'dnetwo-bot' ); ?> <a href="<?php echo esc_url( admin_url( 'admin.php?page=dnetwo-bot-general' ) ) ?>"><?php _e( 'this page', 'dnetwo-bot' ); ?></a>.</p>
                <?php

			}

			?>
        </div>
		<?php
	}

	public static function display_notice() {
		$screen = get_current_screen();

		if ($screen->id === 'dnetwo-bot_page_dnetwo-bot-general') {
			settings_errors();
		}
	}

	public static function load_resources() {
		wp_enqueue_style( 'dnetwo-bot-plugin-style', DNETWO_BOT_PLUGIN_URL . 'assets/css/style.css', null, DNETWO_BOT_VERSION );
	}

	public static function update_bots() {
		$nonce = $_POST['update_bots_nonce'];

		if ( ! empty( $nonce ) || wp_verify_nonce( $nonce, 'update_bots' ) ) {
		    $bots = esc_sql( $_POST['bots'] );

		    if ( is_array( $bots ) ) {
			    foreach ( $bots as $k => $v ) {
				    $page_ids = esc_sql( $bots[ $k ]['page_ids'] );
				    $active = esc_sql( $bots[ $k ]['active'][0] );

				    if ( ( $page_ids_key_for_remove = array_search( 'empty', $page_ids ) ) !== false ) {
					    unset( $page_ids[ $page_ids_key_for_remove ] );
				    }

				    $page_ids = implode( ', ', $page_ids );
				    $active = ( $active == 'yes' );

				    DnetwoBot_Model::update_bot( $k, array(
                        'page_ids' => $page_ids,
                        'active' => $active,
                    ) );
		        }
            }

			$_SESSION['updated'] = true;
		}

		$location = $_POST['_wp_http_referer'];
		wp_safe_redirect( $location );
		exit();
	}

	public static function start_session() {
		if ( ! session_id() ) {
			session_start();
		}
    }

	public static function end_session() {
		session_destroy();
	}
}
