<?php

class DnetwoBot {
	private static $initiated = false;

	public static function init() {
		if ( ! self::$initiated ) {
			self::init_hooks();
		}
	}

	private static function init_hooks() {
		self::$initiated = true;

		add_action( 'wp_head', array( 'DnetwoBot', 'plugin_script' ) );
		add_action( 'wp_footer', array( 'DnetwoBot', 'plugin_iframe' ) );
	}

	public static function plugin_script() {
		?>
        <script>
            var eventMethod = window.addEventListener ? 'addEventListener' : 'attachEvent';
            var eventer = window[eventMethod];
            var messageEvent = eventMethod === 'attachEvent' ? 'onmessage' : 'message';
            eventer(messageEvent, function (event) {
                if (undefined === event.data || undefined === event.data.opened) {
                    return;
                }
                var responsiveFrame = document.getElementById('responsiveFrame');
                responsiveFrame.style.height = event.data.opened ? '75vh' : '65px';
                responsiveFrame.style.width = event.data.opened ? '400px' : '65px';
                responsiveFrame.style.minWidth = event.data.opened ? '400px' : '65px';
                responsiveFrame.style.minHeight = event.data.opened ? '400px' : '65px';
            }, false);
        </script>
		<?php
    }

    public static function plugin_iframe() {
	    if ( is_page() || is_single() ) {
		    global $post;

		    $customer_id = DnetwoBot_Helper::get_option_value( 'option_name', 'customer_id' );

		    if ( $bot = DnetwoBot_Model::get_frontend_bot( $customer_id, $post->ID ) ) {
			    $bot_src = DnetwoBot_Model::prepare_bot_src( $bot->bot_link );
			    ?>
                <iframe id="responsiveFrame" src="<?php echo $bot_src; ?>"
                        align="bottom"
                        style=" bottom: 0; right: 0; position: fixed; float: right; height: 75vh; max-height: 100%; min-width: 400px; min-height: 400px;"
                        allowtransparency="true" frameborder="0"></iframe>
			    <?php
		    }
	    }
    }

	private static function bail_on_activation( $message, $deactivate = true ) {
        ?>
        <!doctype html>
        <html>
        <head>
            <meta charset="<?php bloginfo( 'charset' ); ?>">
            <style>
                * {
                    text-align: center;
                    margin: 0;
                    padding: 0;
                    font-family: "Lucida Grande", Verdana, Arial, "Bitstream Vera Sans", sans-serif;
                }

                p {
                    margin-top: 1em;
                    font-size: 18px;
                }
            </style>
        </head>
        <body>
        <p><?php echo esc_html( $message ); ?></p>
        </body>
        </html>
        <?php

		if ( $deactivate ) {
			$plugins = get_option( 'active_plugins' );
			$dnetwo_bot = plugin_basename( DNETWO_BOT_PLUGIN_DIR . 'dnetwo-bot.php' );
			$update  = false;
			foreach ( $plugins as $i => $plugin ) {
				if ( $plugin === $dnetwo_bot ) {
					$plugins[ $i ] = false;
					$update        = true;
				}
			}

			if ( $update ) {
				update_option( 'active_plugins', array_filter( $plugins ) );
			}
		}
		exit;
	}

	public static function plugin_activation() {
		if ( version_compare( $GLOBALS['wp_version'], DNETWO_BOT_MINIMUM_WP_VERSION, '<' ) ) {
			load_plugin_textdomain( 'dnetwo-bot' );

			$message = sprintf(
				esc_html__( 'dnetwo.bot %s requires WordPress %s or higher.', 'dnetwo-bot' ),
				DNETWO_BOT_VERSION, DNETWO_BOT_MINIMUM_WP_VERSION
			);
			$message = "<strong>$message</strong>";

			self::bail_on_activation( $message );
		}

		global $wpdb;

		$table_name = $wpdb->prefix . DNETWO_BOT_TABLE_NAME;
		$charset_collate = $wpdb->get_charset_collate();

        $sql = "CREATE TABLE `{$table_name}` (
            id BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
            customer_id VARCHAR(100) NOT NULL,
            bot_key VARCHAR(100) NOT NULL,
            bot_name VARCHAR(100) NOT NULL,
            bot_link VARCHAR(255) NOT NULL,
            page_ids VARCHAR(255) NOT NULL,
            active TINYINT(1) UNSIGNED NOT NULL DEFAULT 1,
            PRIMARY KEY  (id),
            UNIQUE (bot_key)
        ) $charset_collate";

		require_once( DNETWO_BOT_WPROOTPATH . 'wp-admin/includes/upgrade.php' );
		@dbDelta( $sql );
	}

	public static function plugin_deactivation() {
		// ...
	}
}
